﻿; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below.
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = "TripleKFPalm"   ;Same name as above
command = ~D, DF, F, D, DF, F, y
time = 20

[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, ~x
time = 20

[Command]
name = "TripleKFPalm"   ;Same name as above
command = ~D, DF, F, D, DF, F, ~y
time = 20

[Command]
name = "SmashKFUpper"
command = ~D, DB, B, D, DB, B, x;~F, D, DF, F, D, DF, x
time = 20

[Command]
name = "SmashKFUpper"   ;Same name as above
command = ~D, DB, B, D, DB, B, y;~F, D, DF, F, D, DF, y
time = 20

[Command]
name = "SmashKFUpper"
command = ~D, DB, B, D, DB, B, ~x;~F, D, DF, F, D, DF, ~x
time = 20

[Command]
name = "SmashKFUpper"   ;Same name as above
command = ~D, DB, B, D, DB, B, ~y;~F, D, DF, F, D, DF, ~y
time = 20

[Command]
name = "ChargeKFPalm"
command = ~D, DF, F, D, DF, F, x+y
time = 20

[Command]
name = "ChargeKFUpper"
command = ~D, DB, B, D, DB, B, x+y
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "blocking"
command = $F,x
time = 3

[Command]
name = "blocking" ;Same name as above (buttons in opposite order)
command = x,$F
time = 3

[Command]
name = "kick_a"
command = ~D, DB, B, a

[Command]
name = "kick_b"
command = ~D, DB, B, b

[Command]
name = "kick_a"
command = ~D, DB, B, ~a

[Command]
name = "kick_b"
command = ~D, DB, B, ~b

[Command]
name = "kick_ab"
command = ~D, DB, B, a+b

[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_x"
command = ~F, D, DF, ~x

[Command]
name = "upper_y"
command = ~F, D, DF, ~y

[Command]
name = "upper_xy"
command = ~F, D, DF, x+y

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_x"
command = ~D, DF, F, ~x

[Command]
name = "QCF_y"
command = ~D, DF, F, ~y

[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_x"
command = ~D, DB, B, ~x

[Command]
name = "QCB_y"
command = ~D, DB, B, ~y

[Command]
name = "QCB_xy"
command = ~D, DB, B, x+y

[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCF_a"
command = ~D, DF, F, ~a

[Command]
name = "QCF_b"
command = ~D, DF, F, ~b

[Command]
name = "QCF_ab"
command = ~D, DF, F, a+b

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

[Command]
name = "FF_a"
command = F, F, ~a

[Command]
name = "FF_b"
command = F, F, ~b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "x+y"
command = x+y
time = 1

[Command]
name = "a+b"
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "back_x"
command = /$B,x
time = 1

[Command]
name = "back_y"
command = /$B,y
time = 1

[Command]
name = "back_z"
command = /$B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_x"
command = /$F,x
time = 1

[Command]
name = "fwd_y"
command = /$F,y
time = 1

[Command]
name = "fwd_z"
command = /$F,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "back_a"
command = /$B,a
time = 1

[Command]
name = "back_b"
command = /$B,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_a"
command = /$F,a
time = 1

[Command]
name = "fwd_b"
command = /$F,b
time = 1

[Command]
name = "fwd_c"
command = /$F,c
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "fwd"
command = $F
time = 1

[Command]
name = "down"
command = $D
time = 1

[Command]
name = "back"
command = $B
time = 1

[Command]
name = "up"
command = $U
time = 1

[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd" ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holddownfwd"
command = /$DF
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddownback"
command = /$DB
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdupback"
command = /$UB
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holdupfwd"
command = /$UF
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;Charge Kung Fu Upper (uses two super bars)
[State -1, Smash Kung Fu Upper]
type = ChangeState
value = 3150
triggerall = AILevel <= 0
triggerall = command = "ChargeKFUpper"
triggerall = power >= 2000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3050,3100)
trigger2 = movecontact
trigger3 = stateno = 1310 || stateno = 1330 ;From blocking

;---------------------------------------------------------------------------
;Charge Kung Fu Palm (uses two super bars)
[State -1, Charge Kung Fu Palm]
type = ChangeState
value = 3100
triggerall = AILevel <= 0
triggerall = command = "ChargeKFPalm"
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3000,3050)
trigger2 = movecontact
trigger3 = stateno = 1310 || stateno = 1330 ;From blocking

;---------------------------------------------------------------------------
;Smash Kung Fu Upper (uses one super bar)
[State -1, Smash Kung Fu Upper]
type = ChangeState
value = 3050
triggerall = AILevel <= 0
triggerall = command = "SmashKFUpper"
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3050,3100)
trigger2 = movecontact
trigger3 = stateno = 1310 || stateno = 1330 ;From blocking

;---------------------------------------------------------------------------
;Triple Kung Fu Palm (uses one super bar)
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3000
triggerall = AILevel <= 0
triggerall = command = "TripleKFPalm"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3000,3050)
trigger2 = movecontact
trigger3 = stateno = 1310 || stateno = 1330 ;From blocking

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact
trigger3 = stateno = 1310 || stateno = 1330 ;From blocking
var(1) = 1

;---------------------------------------------------------------------------
;Fast Kung Fu Knee (1/3 super bar)
[State -1, Fast Kung Fu Knee]
type = ChangeState
value = 1070
triggerall = AILevel <= 0
triggerall = command = "FF_ab"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Knee
[State -1, Light Kung Fu Knee]
type = ChangeState
value = 1050
triggerall = AILevel <= 0
triggerall = command = "FF_a"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Knee
[State -1, Strong Kung Fu Knee]
type = ChangeState
value = 1060
triggerall = AILevel <= 0
triggerall = command = "FF_b"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Palm (1/3 super bar)
[State -1, Fast Kung Fu Palm]
type = ChangeState
value = 1020
triggerall = AILevel <= 0
triggerall = command = "QCF_xy"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Palm
[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1000
triggerall = AILevel <= 0
triggerall = command = "QCF_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Palm
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1010
triggerall = AILevel <= 0
triggerall = command = "QCF_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Upper (1/3 super bar)
[State -1, Fast Kung Fu Upper]
type = ChangeState
value = 1120
triggerall = AILevel <= 0
triggerall = command = "upper_xy"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Upper
[State -1, Light Kung Fu Upper]
type = ChangeState
value = 1100
triggerall = AILevel <= 0
triggerall = command = "upper_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Upper
[State -1, Strong Kung Fu Upper]
type = ChangeState
value = 1110
triggerall = AILevel <= 0
triggerall = command = "upper_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Blow (1/3 super bar)
[State -1, Fast Kung Fu Blow]
type = ChangeState
value = 1220
triggerall = AILevel <= 0
triggerall = command = "QCB_xy"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Blow
[State -1, Light Kung Fu Blow]
type = ChangeState
value = 1200
triggerall = AILevel <= 0
triggerall = command = "QCB_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 1210
triggerall = AILevel <= 0
triggerall = command = "QCB_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;High Kung Fu Blocking (High)
[State -1, High Kung Fu Blocking High]
type = ChangeState
value = 1300
triggerall = AILevel <= 0
triggerall = command = "blocking"
triggerall = command != "holddown"
trigger1 = ctrl
trigger1 = statetype != A
trigger2 = stateno = 1310 || stateno = 1330
trigger2 = time > 0

;---------------------------------------------------------------------------
;High Kung Fu Blocking (Low)
[State -1, High Kung Fu Blocking Low]
type = ChangeState
value = 1320
triggerall = AILevel <= 0
triggerall = command = "blocking"
triggerall = command = "holddown"
trigger1 = ctrl
trigger1 = statetype != A
trigger2 = stateno = 1310 || stateno = 1330
trigger2 = time > 0

;---------------------------------------------------------------------------
;High Kung Fu Blocking (Air)
[State -1, High Kung Fu Blocking Low]
type = ChangeState
value = 1340
triggerall = AILevel <= 0
triggerall = command = "blocking"
triggerall = command != "holdup"
triggerall = command != "holddown"
trigger1 = ctrl
trigger1 = statetype = A
trigger2 = stateno = 1350
trigger2 = time > 0

;---------------------------------------------------------------------------
;Far Kung Fu Zankou
[State -1, Far Kung Fu Zankou]
type = ChangeState
value = 1420
triggerall = AILevel <= 0
triggerall = command = "QCF_ab"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Zankou
[State -1, Light Kung Fu Zankou]
type = ChangeState
value = 1400
triggerall = AILevel <= 0
triggerall = command = "QCF_a"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Zankou
[State -1, Strong Kung Fu Zankou]
type = ChangeState
value = 1410
triggerall = AILevel <= 0
triggerall = command = "QCF_b"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Flying Kick
[State -1, Fast Kung Fu Kick]
type = ChangeState
value = 1520
triggerall = AILevel <= 0
triggerall = command = "kick_ab"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Flying Kick
[State -1, Light Kung Fu Kick]
type = ChangeState
value = 1500
triggerall = AILevel <= 0
triggerall = command = "kick_a"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Flying Kick
[State -1, Strong Kung Fu Kick]
type = ChangeState
value = 1510
triggerall = AILevel <= 0
triggerall = command = "kick_b"
trigger1 = var(1) ;Use combo condition (above)

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Kung Fu Throw
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = ctrl
triggerall = AILevel <= 0
triggerall = command = "y"
triggerall = statetype = S
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 10
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 10
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;Kung Fu Air Throw
[State -1, Kung Fu Throw]
type = ChangeState
value = 805
triggerall = ctrl
triggerall = AILevel <= 0
triggerall = command = "y"
triggerall = statetype = A
triggerall = p2bodydist y >= -50
triggerall = p2bodydist y <= 50
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 10
trigger1 = (p2statetype = A)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 10
trigger2 = (p2statetype = A)
trigger2 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = AILevel <= 0
triggerall = command = "x+y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
;Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = AILevel <= 0
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 6

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = AILevel <= 0
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = AILevel <= 0
triggerall = command = "a+b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = AILevel <= 0
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 7
trigger3 = (stateno = 230) && time > 9

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = AILevel <= 0
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = AILevel <= 0
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = AILevel <= 0
triggerall = command = "x+y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = AILevel <= 0
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = AILevel <= 0
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = AILevel <= 0
triggerall = command = "a+b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = AILevel <= 0
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = AILevel <= 0
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = AILevel <= 0
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 7
trigger3 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = AILevel <= 0
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = AILevel <= 0
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = AILevel <= 0
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking

;===========================================================================
;---------------------------------------------------------------------------
; AI System
;---------------------------------------------------------------------------
; Random AI
[State -1, Random]
type = VarRandom
trigger1 = Ctrl
trigger1 = AILevel > 0
trigger1 = RoundState = 2
ignorehitpause = 1
v = 30
range = 0,100

[State -1, VarSet]
type = VarSet
trigger1 = AILevel <= 0
trigger2 = RoundState != 2
ignorehitpause = 1
v = 30
value = 0

;----- Kung Fu Throw -----
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = Time > 0
triggerall = AILevel > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
triggerall = (P2StateType = S) || (P2StateType = C)
trigger1 = P2MoveType != H
trigger1 = P2BodyDist X <= 10
trigger1 = Var(30) > 0
trigger1 = Var(30) < 10
trigger1 = Ctrl
ignorehitpause = 1

[State -1, Kung Fu Air Throw]
type = ChangeState
value = 805
triggerall = Time > 0
triggerall = AILevel > 0
triggerall = statetype = A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
triggerall = P2StateType = A
trigger1 = P2MoveType != H
trigger1 = P2BodyDist X <= 10
trigger1 = P2BodyDist y >= -50
trigger1 = P2BodyDist y <= 50
trigger1 = Var(30) > 0
trigger1 = Var(30) < 10
trigger1 = Ctrl
trigger2 = StateNo = 610 || StateNo = 640
trigger2 = MoveContact
ignorehitpause = 1
;-------------------------

;===== Super Moves =====
;--------------------
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3000
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = power >= 1000
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = P2BodyDist X >= 100
trigger1 = Var(30) = 100
trigger1 = Ctrl
trigger2 = StateNo >= 1000
trigger2 = StateNo <= 1020
trigger2 = MoveContact
trigger2 = Var(10) > 1
ignorehitpause = 1

;--------------------
[State -1, Smash Kung Fu Upper]
type = ChangeState
value = 3050
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = power >= 1000
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
triggerall = P2BodyDist X <= 50
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = Var(30) = 96
trigger1 = Ctrl
trigger2 = Anim = 3000
trigger2 = AnimElem = 22, >= 0
trigger2 = P2StateType = A
trigger2 = Var(10) > 1
trigger2 = MoveContact
trigger3 = Anim = 1110
trigger3 = AnimElem = 8, >= 0
trigger3 = Var(10) > 1
trigger3 = MoveContact
trigger4 = PrevStateNo = 1210
trigger4 = StateNo = 1410
trigger4 = MoveContact
trigger4 = Var(10) > 1
ignorehitpause = 1

;--------------------
[State -1, Charge Kung Fu Palm]
type = ChangeState
value = 3100
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = power >= 2000
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = Var(30) = 98
trigger1 = Ctrl
ignorehitpause = 1

;--------------------
[State -1, Charge Kung Fu Upper]
type = ChangeState
value = 3150
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = power >= 2000
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = Var(30) = 94
trigger1 = Ctrl
ignorehitpause = 1
;=========================

;===== Fast Moves =====
;--------------------
[State -1, Fast Kung Fu Kick]
type = ChangeState
value = 1520
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = power >= 330
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = Var(30) = 65
trigger1 = Ctrl
ignorehitpause = 1

;--------------------
[State -1, Far Kung Fu Zankou]
type = ChangeState
value = 1420
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = power >= 330
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = P2BodyDist X > 100
trigger1 = Var(30) = 55
trigger1 = Ctrl
ignorehitpause = 1

;--------------------
[State -1, Fast Kung Fu Blow]
type = ChangeState
value = 1220
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = power >= 330
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = P2BodyDist X <= 100
trigger1 = Var(30) = 45
trigger1 = Ctrl
ignorehitpause = 1

;--------------------
[State -1, Fast Kung Fu Upper]
type = ChangeState
value = 1120
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = power >= 330
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = P2BodyDist X <= 50
trigger1 = Var(30) = 35
trigger1 = Ctrl
ignorehitpause = 1

;--------------------
[State -1, Fast Kung Fu Knee]
type = ChangeState
value = 1070
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = power >= 330
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
triggerall = P2StateType = A
trigger1 = P2MoveType != H
trigger1 = Var(30) = 25
trigger1 = Ctrl
ignorehitpause = 1

;--------------------
[State -1, Fast Kung Fu Palm]
type = ChangeState
value = 1020
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = power >= 330
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = Var(30) = 15
trigger1 = Ctrl
ignorehitpause = 1
;=========================

;===== Special Moves =====
;--------------------
[State -1, Strong Kung Fu Kick]
type = ChangeState
value = 1510
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = Var(30) >= 15
trigger1 = Var(30) < 20
trigger1 = Ctrl
ignorehitpause = 1

;--------------------
[State -1, Strong Kung Fu Zankou]
type = ChangeState
value = 1410
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
triggerall = P2BodyDist X <= 100
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = Var(30) >= 50
trigger1 = Var(30) < 55
trigger1 = Ctrl
trigger2 = PrevStateNo != 410
trigger2 = StateNo = 1210
trigger2 = MoveContact
trigger2 = Var(10) > 1
ignorehitpause = 1

;--------------------
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 1210
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = P2BodyDist X <= 100
trigger1 = Var(30) >= 40
trigger1 = Var(30) < 45
trigger1 = Ctrl
trigger2 = Anim = 410
trigger2 = AnimElem = 4 >= 0
trigger2 = Var(10) > 1
trigger2 = MoveContact
trigger3 = StateNo = 440
trigger3 = MoveContact
trigger3 = Var(10) > 1
ignorehitpause = 1

;--------------------
[State -1, Strong Kung Fu Upper]
type = ChangeState
value = 1110
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = P2BodyDist X <= 50
trigger1 = Var(30) >= 30
trigger1 = Var(30) < 35
trigger1 = Ctrl
ignorehitpause = 1

;--------------------
[State -1, Strong Kung Fu Knee]
type = ChangeState
value = 1060
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
triggerall = P2StateType = A
trigger1 = P2MoveType != H
trigger1 = Var(30) >= 20
trigger1 = Var(30) < 25
trigger1 = Ctrl
ignorehitpause = 1

;--------------------
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1010
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = Var(30) >= 10
trigger1 = Var(30) < 15
trigger1 = Ctrl
trigger2 = StateNo = 220 || StateNo = 240 || StateNo = 250
trigger2 = Var(10) > 1
trigger2 = MoveContact
trigger3 = PrevStateNo = 410
trigger3 = StateNo = 1210
trigger3 = MoveContact
trigger3 = Var(10) > 1
ignorehitpause = 1
;=========================

;===== Normal Moves =====
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = Ctrl
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
triggerall = P2BodyDist X <= 50
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = Var(30) >= 60
trigger1 = Var(30) < 65
ignorehitpause = 1

[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = StateNo = 200
trigger1 = MoveContact
trigger1 = Var(10) > 1
ignorehitpause = 1

[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = StateNo = 210
trigger1 = MoveContact
trigger1 = Var(10) > 1
ignorehitpause = 1

[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = Ctrl
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
triggerall = P2BodyDist X <= 50
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = Var(30) >= 70
trigger1 = Var(30) < 75
ignorehitpause = 1

[State -1, Stand Strong Kick]
type = ChangeState
value = 240
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = StateNo = 230
trigger1 = MoveContact
trigger1 = Var(10) > 1
ignorehitpause = 1

[State -1, Stand Strong Kick]
type = ChangeState
value = 250
triggerall = Ctrl
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2MoveType != H
trigger1 = Var(30) >= 75
trigger1 = Var(30) < 80
ignorehitpause = 1

[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = Ctrl
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
triggerall = P2BodyDist X <= 50
trigger1 = P2StateType != L
trigger1 = P2StateType = S
trigger1 = P2MoveType = A
trigger2 = P2MoveType != H
trigger2 = Var(30) >= 80
trigger2 = Var(30) < 85
trigger3 = P2StateType = C
ignorehitpause = 1

[State -1, Crouching Strong Punch]
type = ChangeState
value = IfElse(P2StateType != C, 410, 430)
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = StateNo = 400
trigger1 = Var(10) > 1
trigger1 = MoveContact
trigger2 = P2StateType != L
trigger2 = P2MoveType != H
trigger2 = StateNo = 430
trigger2 = Var(10) > 1
trigger2 = MoveHit
ignorehitpause = 1

[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = Ctrl
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2BodyDist X <= 50
trigger1 = P2StateType != L
trigger1 = P2MoveType != H
trigger1 = Var(30) >= 90
trigger1 = Var(30) < 95
trigger2 = P2BodyDist X <= 50
trigger2 = P2StateType = L
ignorehitpause = 1

[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2StateType != A || P2StateType = L
trigger1 = StateNo = 430
trigger1 = MoveContact
trigger1 = Var(10) > 1
ignorehitpause = 1

[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = Ctrl
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype != A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
triggerall = P2BodyDist X > 50
trigger1 = P2StateType != L
trigger1 = P2StateType = S
trigger1 = P2MoveType = A
trigger2 = P2MoveType != H
trigger2 = Var(30) >= 80
trigger2 = Var(30) < 85
trigger3 = P2StateType = C
ignorehitpause = 1

[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = Ctrl
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype = A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = Var(30) > 0
trigger1 = Var(30) < 10
ignorehitpause = 1

[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype = A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = StateNo = 600
trigger1 = MoveContact
trigger1 = Var(10) > 1
ignorehitpause = 1

[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = Ctrl
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype = A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = P2StateType = A
trigger2 = Var(30) >= 10
trigger2 = Var(30) < 20
ignorehitpause = 1

[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = statetype = A
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
trigger1 = StateNo = 630
trigger1 = MoveContact
trigger1 = Var(10) > 1
ignorehitpause = 1
;=========================

;----- Blocking -----
[State -1, StandBlock]
type = ChangeState
value = 1300
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = StateType != L
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
triggerall = P2StateType = S || P2StateType = A
triggerall = P2MoveType = A
triggerall = P2BodyDist X >= 50
trigger1 = StateType != A
trigger1 = MoveType = I
trigger1 = Ctrl
trigger2 = StateNo >= 1300
trigger2 = StateNo < 1320
value = 1300

[State -1, CrouchBlock]
type = ChangeState
value = 1320
triggerall = Time > 0
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = StateType != L
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
triggerall = P2StateType = C
triggerall = P2MoveType = A
triggerall = P2BodyDist X >= 50
trigger1 = StateType != A
trigger1 = MoveType = I
trigger1 = Ctrl
trigger2 = StateNo >= 1320
trigger2 = StateNo < 1340

[State -1, AirBlock]
type = ChangeState
value = 1340
triggerall = Time > 0
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = StateType != L
triggerall = EnemyNear, Alive
triggerall = P2Life > 0
triggerall = P2StateType = S || P2StateType = A
triggerall = P2MoveType = A
triggerall = P2BodyDist X >= 50
trigger1 = StateType = A
trigger1 = MoveType = I
trigger1 = Ctrl
trigger2 = StateNo >= 1340
trigger2 = StateNo < 1360
;--------------------

;--------------------
; Stand Guard
[State -1, Guard]
type = ChangeState
value = 130
triggerall = Ctrl
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = StateNo < 160
triggerall = StateType != A
trigger1 = EnemyNear, StateType != C
trigger1 = EnemyNear, MoveType = A
trigger1 = P2Dist X <= 50

; Crouch Guard
[State -1, Guard]
type = ChangeState
value = 131
triggerall = Ctrl
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = StateNo < 160
triggerall = StateType != A
trigger1 = EnemyNear, StateType = C
trigger1 = EnemyNear, MoveType = A
trigger1 = P2Dist X <= 50

; Air Guard
[State -1, Guard]
type = ChangeState
value = 132
triggerall = Ctrl
triggerall = AILevel > 0
triggerall = Var(30) > 0
triggerall = StateNo < 160
triggerall = StateType = A
trigger1 = EnemyNear, StateType != C
trigger1 = EnemyNear, MoveType = A
trigger1 = P2Dist X <= 50
;--------------------

;---------------------------------------------------------------------------